<?php
/**
 * Context consumer block.
 *
 * @param array  $block The block settings and attributes.
 * @param string $content The block inner HTML (empty).
 * @param bool   $is_preview True during backend preview render.
 * @param int    $post_id The post ID the block is rendering content against.
 *                     This is either the post ID currently being displayed inside a query loop,
 *                     or the post ID of the post hosting this block.
 * @param array $context The context provided to the block by the post or it's parent block.
 */

// Support custom "anchor" values.
$anchor = '';
if ( ! empty( $block['anchor'] ) ) {
	$anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
}

// Create class attribute allowing for custom "className" and "align" values.
$class_name = 'context-consumer';
if ( ! empty( $block['className'] ) ) {
	$class_name .= ' ' . $block['className'];
}
if ( ! empty( $block['align'] ) ) {
	$class_name .= ' align' . $block['align'];
}
?>

<div <?php echo esc_attr( $anchor ); ?>class="<?php echo esc_attr( $class_name ); ?>">
	<h4 style="margin-top: 0;margin-bottom:0;">ACF <strong>Context <span class="highlight highlight--consumer">Consumer</span></strong> Block</h4>

	<p>Hi, I'm a nested ACF Block in <code>&lt;InnerBlocks&gt;</code>, but I'm displaying the information from my parent ACF Block by consuming its established block context.</p>
	
	<p>Here I will display the value of the parent block's field for the <code>parent_context_provider</code> when and if it has a value: <strong><?php echo esc_html( $context['acf/fields']['field_65aaeac1b72b5'] ?? $context['acf/fields']['parent_context_provider'] ); ?></strong></p>
	
	<pre><?php var_dump( $context ); ?></pre>
</div>